@@ -1,4 +1,5 @@
 import requests
+import time
 
 token = ''
 
@@ -7,12 +8,10 @@ class testRequest:
   def __init__(self):
     self.text = 'Thinking'
 
-def login(token):
-  token = ''
-
 class ChatBot:
   #getAnswer: wait for answer and return it
   def __init__(self, id, name, language):
+    self.thinking = False
     self.id = id
     self.name = name
     self.language = language
@@ -29,7 +28,8 @@ class ChatBot:
     except Exception as es:
       print(es)
       x = ''
+    self.thinking = False
     return x
     #reset: reset the chatbot
-    def reset(self):
-      requests.patch('https://api.daniton999.ml/chatbot', json = {'token': token, 'id': self.id, 'language': self.language, 'name': self.name})
+  def reset(self):
+    requests.patch('https://api.daniton999.ml/chatbot', json = {'token': token, 'id': self.id, 'language': self.language, 'name': self.name})
